@@ -1,5 +1,6 @@
-# TODO: add links to docs
+from __future__ import annotations
 
+from enum import Enum
 from typing import List, Set, Union
 
 from graphql import GraphQLObjectType
@@ -7,13 +8,47 @@ from graphql import GraphQLObjectType
 from strawberry.type import StrawberryType
 
 
-class NotAnEnum(Exception):
-    def __init__(self):
-        message = "strawberry.enum can only be used with subclasses of Enum"
+# TODO: add links to docs
+# https://github.com/strawberry-graphql/strawberry/issues/1298
+
+
+class ObjectIsNotAnEnumError(Exception):
+    def __init__(self, obj: object):
+        message = (
+            "strawberry.enum can only be used with subclasses of Enum. "
+            f"Provided object {obj} is not an enum."
+        )
 
         super().__init__(message)
 
 
+class ObjectIsNotClassError(Exception):
+    class MethodType(Enum):
+        INPUT = "input"
+        INTERFACE = "interface"
+        TYPE = "type"
+
+    def __init__(self, obj: object, method_type: MethodType):
+        message = (
+            f"strawberry.{method_type.value} can only be used with class types. "
+            f"Provided object {obj} is not a type."
+        )
+
+        super().__init__(message)
+
+    @classmethod
+    def input(cls, obj: object) -> ObjectIsNotClassError:
+        return cls(obj, cls.MethodType.INPUT)
+
+    @classmethod
+    def interface(cls, obj: object) -> ObjectIsNotClassError:
+        return cls(obj, cls.MethodType.INTERFACE)
+
+    @classmethod
+    def type(cls, obj: object) -> ObjectIsNotClassError:
+        return cls(obj, cls.MethodType.TYPE)
+
+
 class MissingReturnAnnotationError(Exception):
     """The field is missing the return annotation"""
 
@@ -173,6 +208,15 @@ class MissingQueryError(Exception):
 
 class InvalidFieldArgument(Exception):
     def __init__(self, field_name: str, argument_name: str, argument_type: str):
-        message = f'Argument "{argument_name}" on field "{field_name}" cannot be of type\
-            "{argument_type}"'
+        message = (
+            f'Argument "{argument_name}" on field "{field_name}" cannot be of type '
+            f'"{argument_type}"'
+        )
+        super().__init__(message)
+
+
+class InvalidDefaultFactoryError(Exception):
+    def __init__(self):
+        message = "`default_factory` must be a callable that requires no arguments"
+
         super().__init__(message)
