@@ -1,4 +1,4 @@
-from typing import Any, Type
+from typing import Any, List, Type
 
 from pydantic import BaseModel
 from pydantic.typing import NoArgAnyCallable
@@ -35,3 +35,13 @@ class BothDefaultAndDefaultFactoryDefinedError(Exception):
         )
 
         super().__init__(message)
+
+
+class AutoFieldsNotInBaseModelError(Exception):
+    def __init__(self, fields: List[str], cls_name: str, model: Type[BaseModel]):
+        message = (
+            f"{cls_name} defines {fields} with strawberry.auto. "
+            f"Field(s) not present in {model.__name__} BaseModel."
+        )
+
+        super().__init__(message)
